@@ -32,7 +32,10 @@ class retrieveAlbum(QtCore.QThread):
 		if datastart > 30:
 			dataend = page.find('"',datastart)
 			self.iUrl = page[datastart:dataend]
-			self.emit(QtCore.SIGNAL("album"))
+		else:
+			self.iUrl = "None"
+			
+		self.emit(QtCore.SIGNAL("album"))
 		self.response.close
 
 class Config:
@@ -375,8 +378,11 @@ class MyForm(QtGui.QMainWindow):
 			self.p.playing = 1
 
 	def uAlbum(self):
-		myUrl = QtCore.QUrl.fromEncoded(self.a.iUrl)
-		self.ui.albumArt.load(myUrl)
+		if not self.a.iUrl == "None":
+			myUrl = QtCore.QUrl.fromEncoded(self.a.iUrl)
+			self.ui.albumArt.load(myUrl)
+		else:
+			self.ui.albumArt.setHtml("<img src='qrc:///img/img/no-image-trans.png'>")
 		
 	def doLove(self):
 		if self.p.last == "song":
